'use strict';

var quickSearchWidgetReact = require('@recombee/quick-search-widget-react');
var react$1 = require('react');
var client = require('react-dom/client');
var react = require('htm/react');

/**
 * # Quick Search Widget (JS)
 *
 * > {{> libraryTypeDescription_Vanilla}} {{> libraryDescription_QuickSearch}}
 *
 * {{> libraryTypeUsage_Vanilla}}
 *
 * {{> preStableReleaseDisclaimer}}
 *
 * {{> widgetIntallationSectionDefault packageName="@recombee/quick-search-widget-js" }}
 *
 * {{> widgetClientInitializationSectionDefault }}
 *
 * ## Basic Example {#basic-example}
 *
 * {{> basicExampleCommonContent }}
 *
 * @example
 *
 * {@includeExample ../examples/basic-example}
 *
 * ## Custom Template {#custom-template}
 *
 * @example
 *
 * {@includeExample ../examples/custom-template}
 *
 * ## Batch Request {#batch-request}
 *
 * To fetch results from multiple Scenarios, such as segments in addition to items, use Batch
 * request.
 *
 * @example
 *
 * {@includeExample ../examples/multiple-requests}
 *
 * @public
 * @packageDocumentation
 */
/** End packageDocumentation */
const roots = new WeakMap();
/**
 * Quick Search widget
 *
 * @public
 */
const QuickSearchWidget = ({ container, ...props }) => {
    if (typeof document === 'undefined')
        return null;
    const containerElement = document.querySelector(container);
    if (containerElement) {
        let root = roots.get(containerElement);
        if (!root) {
            root = client.createRoot(containerElement);
            roots.set(containerElement, root);
        }
        const widgetElement = react$1.createElement(quickSearchWidgetReact.QuickSearchWidget, props);
        root.render(widgetElement);
    }
};

exports.QuickSearchWidget = QuickSearchWidget;
Object.keys(quickSearchWidgetReact).forEach(function (k) {
    if (k !== 'default' && !Object.prototype.hasOwnProperty.call(exports, k)) Object.defineProperty(exports, k, {
        enumerable: true,
        get: function () { return quickSearchWidgetReact[k]; }
    });
});
Object.keys(react).forEach(function (k) {
    if (k !== 'default' && !Object.prototype.hasOwnProperty.call(exports, k)) Object.defineProperty(exports, k, {
        enumerable: true,
        get: function () { return react[k]; }
    });
});
